@@ -81,12 +81,18 @@
 #' @keywords influenza
 #'
 #' @export
-memintensity<-function(i.flu){
-  intensity.thresholds<-matrix(c(i.flu$pre.post.intervals[1,3],i.flu$epi.intervals[,4]),ncol=4)
-  colnames(intensity.thresholds)<-c("Epidemic",paste(c("Medium (","High (","Very high ("),as.character(round(i.flu$epi.intervals[,1]*100,1)),"%)",sep=""))
-  rownames(intensity.thresholds)<-"Intensity Thresholds"
-  memintensity.output<-list(intensity.thresholds=intensity.thresholds,
-                            param.i.flu=i.flu)
-  memintensity.output$call<-match.call()
+memintensity <- function(i.flu) {
+  if (is.null(i.flu)) {
+    memintensity.output <- NULL
+  } else {
+    intensity.thresholds <- matrix(c(i.flu$pre.post.intervals[1, 3], i.flu$epi.intervals[, 4]), ncol = 4)
+    colnames(intensity.thresholds) <- c("Epidemic", paste(c("Medium (", "High (", "Very high ("), as.character(round(i.flu$epi.intervals[, 1] * 100, 1)), "%)", sep = ""))
+    rownames(intensity.thresholds) <- "Intensity Thresholds"
+    memintensity.output <- list(
+      intensity.thresholds = intensity.thresholds,
+      param.i.flu = i.flu
+    )
+    memintensity.output$call <- match.call()
+  }
   return(memintensity.output)
 }
